@@ -6,8 +6,8 @@
 ;; Author: HIGASHI Taiju (2020-2024), Isa Mert Gurbuz (2024-)
 ;; Keywords: literate programming, reproducible research, javascript, typescript, tools, deno
 ;; Homepage: https://github.com/isamert/ob-deno
-;; Package-Version: 20250913.1628
-;; Package-Revision: d9225ecf2e4e
+;; Package-Version: 20260213.1023
+;; Package-Revision: 77beef624ff2
 ;; Package-Requires: ((emacs "29.1"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
@@ -52,7 +52,7 @@
   :safe #'stringp)
 
 (defcustom ob-deno-function-wrapper
-  "Deno.stdout.write(new TextEncoder().encode(JSON.stringify(await (async () => {%s})(), null, 2)));"
+  "Deno.stdout.write(new TextEncoder().encode(JSON.stringify(await (async () => {\n%s\n})(), null, 2)));"
   "JS/TS code to print value of body.
 %s is replaced with code body, without the imports.  Imports are
 injected to the beginning of the file."
@@ -87,8 +87,9 @@ injected to the beginning of the file."
 IMPORTS are defined at the top and PARAMS are defined right after them.
 REST is appended to the end."
   (concat
-   imports
-   "\n\n"
+   (if (and imports (not (string-empty-p imports)))
+       (concat imports "\n\n")
+     "")
    (org-babel-expand-body:generic
     rest params (org-babel-variable-assignments:deno params))))
 
